@@ -5,6 +5,7 @@ from embiggen.utils import (
     get_models_dataframe,
     get_available_models_for_node_label_prediction,
     get_available_models_for_edge_prediction,
+    get_available_models_for_edge_embedding,
     get_available_models_for_edge_label_prediction,
     get_available_models_for_node_embedding,
 )
@@ -14,6 +15,7 @@ __all__ = [
     "EmbeddingResult",
     "get_models_dataframe",
     "get_available_models_for_node_label_prediction",
+    "get_available_models_for_edge_embedding",
     "get_available_models_for_edge_prediction",
     "get_available_models_for_edge_label_prediction",
     "get_available_models_for_node_embedding",
