@@ -19,6 +19,7 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
         """
         self._is_binary_prediction_task = None
         self._is_multilabel_prediction_task = None
+        self._number_of_output_labels = None
         super().__init__(random_state=random_state)
 
     @classmethod
@@ -125,6 +126,7 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
         support: Optional[Graph] = None,
         node_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[str, pd.DataFrame, np.ndarray]]]] = None,
         node_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[str, pd.DataFrame, np.ndarray]]]] = None,
+        edge_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
         edge_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[str, pd.DataFrame, np.ndarray]]]] = None,
         subgraph_of_interest: Optional[Graph] = None,
         random_state: int = 42,
@@ -138,17 +140,37 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
             ("train", train),
             ("test", test),
         ):
+            if evaluation_graph.is_directed():
+                mask = evaluation_graph.get_directed_edges_with_known_edge_types_mask()
+            else:
+                mask = evaluation_graph.get_upper_triangular_known_edge_types_mask()
+
             prediction_probabilities = self.predict_proba(
                 evaluation_graph,
                 support=support,
                 node_features=node_features,
                 node_type_features=node_type_features,
                 edge_features=edge_features
-            )[evaluation_graph.get_edge_ids_with_known_edge_types()]
+            )
 
+            if prediction_probabilities.shape[0] != mask.shape[0]:
+                raise RuntimeError(
+                    "The number of predictions and the number of edges "
+                    "in the graph do not match. "
+                    f"Found {prediction_probabilities.shape[0]} predictions "
+                    f"and {mask.shape[0]} edges."
+                )
+
+            prediction_probabilities = prediction_probabilities[mask]
+
+            if evaluation_graph.is_directed():
+                labels = evaluation_graph.get_directed_known_edge_type_ids()
+            else:
+                labels = evaluation_graph.get_upper_triangular_known_edge_type_ids()
+            
             if self.is_binary_prediction_task():
                 predictions = prediction_probabilities
-                labels = evaluation_graph.get_known_edge_type_ids() == 1
+                labels = labels == 1
             elif self.is_multilabel_prediction_task():
                 # TODO! support multilabel prediction!
                 raise NotImplementedError(
@@ -158,7 +180,6 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
                 )
             else:
                 predictions = prediction_probabilities.argmax(axis=-1)
-                labels = evaluation_graph.get_known_edge_type_ids()
 
             performance.append({
                 "evaluation_mode": evaluation_mode,
@@ -182,6 +203,7 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
         support: Optional[Graph] = None,
         node_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
         node_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
+        edge_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
         edge_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
     ):
         """Execute predictions on the provided graph.
@@ -199,6 +221,8 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
             The node features to use.
         node_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
             The node type features to use.
+        edge_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
+            The edge type features to use.
         edge_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
             The edge features to use.
         """
@@ -216,6 +240,7 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
 
         self._is_binary_prediction_task = non_zero_edge_types == 2
         self._is_multilabel_prediction_task = graph.is_multigraph()
+        self._number_of_output_labels = graph.get_number_of_edge_types()
 
         if self._is_multilabel_prediction_task:
             raise ValueError(
@@ -227,6 +252,7 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
             support=support,
             node_features=node_features,
             node_type_features=node_type_features,
+            edge_type_features=edge_type_features,
             edge_features=edge_features,
         )
 
@@ -249,3 +275,38 @@ class AbstractEdgeLabelPredictionModel(AbstractClassifierModel):
     def task_involves_topology(cls) -> bool:
         """Returns whether the model task involves topology."""
         return False
+    
+    def is_using_node_types(self) -> bool:
+        """Whether the current model is using node types."""
+        return self._is_using_node_type_features or self.requires_node_types()
+
+    @classmethod
+    def supports_multilabel_prediction(cls) -> bool:
+        """Returns whether the model supports multilabel prediction.
+        
+        Implementation details
+        ----------------------
+        At this time, no model supports multilabel prediction for the
+        edge label prediction task.
+        """
+        return False
+    
+    @classmethod
+    def can_use_edge_type_features(cls) -> bool:
+        """Returns whether the model can use edge type features."""
+        return False
+    
+    @classmethod
+    def can_use_edge_features(cls) -> bool:
+        """Returns whether the model can use edge features."""
+        return True
+    
+    @classmethod
+    def requires_edge_features(cls) -> bool:
+        """Returns whether the model requires edge features."""
+        return False
+    
+    @classmethod
+    def can_use_node_type_features(cls) -> bool:
+        """Returns whether the model can use node type features."""
+        return True
\ No newline at end of file
