@@ -1,5 +1,5 @@
 """Submodule wrapping Decision Tree for edge label prediction."""
-from typing import Dict, Any
+from typing import Dict, Any, Union, List
 from sklearn.tree import DecisionTreeClassifier
 from embiggen.edge_label_prediction.edge_label_prediction_sklearn.sklearn_edge_label_prediction_adapter import SklearnEdgeLabelPredictionAdapter
 
@@ -15,12 +15,12 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
         min_samples_split=2,
         min_samples_leaf=1,
         min_weight_fraction_leaf=0.,
-        max_features=None,
+        max_features="sqrt",
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
         class_weight="balanced",
         ccp_alpha=0.0,
-        edge_embedding_method: str = "Concatenate",
+        edge_embedding_methods: Union[List[str], str] = "Concatenate",
         use_edge_metrics: bool = False,
         random_state: int = 42
     ):
@@ -53,7 +53,7 @@ class DecisionTreeEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
                 class_weight=class_weight,
                 ccp_alpha=ccp_alpha,
             ),
-            edge_embedding_method=edge_embedding_method,
+            edge_embedding_methods=edge_embedding_methods,
             use_edge_metrics=use_edge_metrics,
             random_state=random_state
         )
