@@ -18,7 +18,7 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
         number_of_units_per_ffnn_body_layer: Union[int, List[int]] = 128,
         number_of_units_per_ffnn_head_layer: Union[int, List[int]] = 128,
         dropout_rate: float = 0.3,
-        edge_embedding_method: str = "Concatenate",
+        edge_embedding_methods: Union[List[str], str] = "Concatenate",
         optimizer: Union[str, Type[Optimizer]] = "adam",
         early_stopping_min_delta: float = 0.0001,
         early_stopping_patience: int = 20,
@@ -36,10 +36,11 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
         node_embedding_size: int = 50,
         use_node_type_embedding: bool = False,
         node_type_embedding_size: int = 50,
+        residual_convolutional_layers: bool = False,
+        siamese_node_feature_module: bool = True,
         handling_multi_graph: str = "warn",
-        node_feature_names: Optional[List[str]] = None,
-        node_type_feature_names: Optional[List[str]] = None,
-        edge_feature_names: Optional[List[str]] = None,
+        node_feature_names: Optional[Union[str, List[str]]] = None,
+        node_type_feature_names: Optional[Union[str, List[str]]] = None,
         verbose: bool = False
     ):
         """Create new GraphSAGE object.
@@ -70,7 +71,7 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
         edge_embedding_method: str = "Concatenate"
             The edge embedding method to use to put togheter the
             source and destination node features, which includes:
-            - Concatenation
+            - Concatenate
             - Average
             - Hadamard
             - L1
@@ -110,22 +111,8 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
         use_class_weights: bool = True
             Whether to use class weights to rebalance the loss relative to unbalanced classes.
             Learn more about class weights here: https://www.tensorflow.org/tutorials/structured_data/imbalanced_data
-        use_node_embedding: bool = False
-            Whether to use a node embedding layer to let the model automatically
-            learn an embedding of the nodes.
-        node_embedding_size: int = 50
-            Size of the node embedding.
-        use_node_types: Union[bool, str] = "auto"
-            Whether to use the node types while training the model.
-            By default, automatically uses them if the graph has them.
-        node_type_embedding_size: int = 50
-            Size of the embedding for the node types.
         training_unbalance_rate: float = 1.0
             Unbalance rate for the training non-existing edges.
-        training_sample_only_edges_with_heterogeneous_node_types: bool = False
-            Whether to only sample edges between heterogeneous node types.
-            This may be useful when training a model to predict between
-            two portions in a bipartite graph.
         use_edge_metrics: bool = False
             Whether to use the edge metrics from traditional edge prediction.
             These metrics currently include:
@@ -149,25 +136,27 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
             and this model will not work on graphs with a different node vocabulary.
         node_type_embedding_size: int = 50
             Dimension of the node type embedding.
+        residual_convolutional_layers: bool = False
+            Whether to use residual connections between convolutional layers.
+        siamese_node_feature_module: bool = True
+            Whether to use a siamese module for the node features.
         handling_multi_graph: str = "warn"
             How to behave when dealing with multigraphs.
             Possible behaviours are:
             - "warn"
             - "raise"
             - "drop"
-        node_feature_names: Optional[List[str]] = None
+        node_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node features.
             This is used as the layer names.
-        node_type_feature_names: Optional[List[str]] = None
+        node_type_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node type features.
             This is used as the layer names.
-        edge_feature_names: Optional[List[str]] = None
-            Names of the edge features.
-            This is used as the layer names.
         verbose: bool = False
             Whether to show loading bars.
         """
         super().__init__(
+            kernels=["Left Normalized Laplacian"],
             epochs=epochs,
             number_of_graph_convolution_layers=number_of_graph_convolution_layers,
             number_of_units_per_graph_convolution_layers=number_of_units_per_graph_convolution_layers,
@@ -178,7 +167,7 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
             dropout_rate=dropout_rate,
             apply_norm=True,
             combiner="mean",
-            edge_embedding_method=edge_embedding_method,
+            edge_embedding_methods=edge_embedding_methods,
             optimizer=optimizer,
             early_stopping_min_delta=early_stopping_min_delta,
             early_stopping_patience=early_stopping_patience,
@@ -192,15 +181,15 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
             use_class_weights=use_class_weights,
             use_edge_metrics=use_edge_metrics,
             random_state=random_state,
-            use_simmetric_normalized_laplacian=False,
             use_node_embedding=use_node_embedding,
             node_embedding_size=node_embedding_size,
             use_node_type_embedding=use_node_type_embedding,
             node_type_embedding_size=node_type_embedding_size,
+            residual_convolutional_layers=residual_convolutional_layers,
+            siamese_node_feature_module=siamese_node_feature_module,
             handling_multi_graph=handling_multi_graph,
             node_feature_names=node_feature_names,
             node_type_feature_names=node_type_feature_names,
-            edge_feature_names=edge_feature_names,
             verbose=verbose,
         )
     
@@ -208,7 +197,7 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
         """Returns parameters for smoke test."""
         removed = [
             "apply_norm",
-            "use_simmetric_normalized_laplacian",
+            "kernels",
             "combiner"
         ]
         return dict(
