@@ -5,6 +5,8 @@ import pandas as pd
 import numpy as np
 from embiggen.utils import classification_evaluation_pipeline, AbstractEmbeddingModel
 from embiggen.edge_prediction.edge_prediction_model import AbstractEdgePredictionModel
+from embiggen.utils.abstract_models import AbstractFeaturePreprocessor
+from embiggen.utils import AbstractEdgeFeature
 
 
 def edge_prediction_evaluation(
@@ -13,7 +15,10 @@ def edge_prediction_evaluation(
     models: Union[Type[AbstractEdgePredictionModel], List[Type[AbstractEdgePredictionModel]]],
     evaluation_schema: str = "Connected Monte Carlo",
     node_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None,
+    edge_features: Optional[Union[str, Type[AbstractEdgeFeature], List[Union[str, Type[AbstractEdgeFeature]]]]] = None,
     node_type_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None,
+    edge_type_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None,
+    node_features_preprocessing_steps: Optional[Union[Type[AbstractFeaturePreprocessor], List[Type[AbstractFeaturePreprocessor]]]] = None,
     library_names: Optional[Union[str, List[str]]] = None,
     graph_callback: Optional[Callable[[Graph], Graph]] = None,
     subgraph_of_interest: Optional[Graph] = None,
@@ -22,14 +27,13 @@ def edge_prediction_evaluation(
     random_state: int = 42,
     repositories: Optional[Union[str, List[str]]] = None,
     versions: Optional[Union[str, List[str]]] = None,
-    validation_sample_only_edges_with_heterogeneous_node_types: bool = False,
     source_node_types_names: Optional[List[str]] = None,
     destination_node_types_names: Optional[List[str]] = None,
     source_edge_types_names: Optional[List[str]] = None,
     destination_edge_types_names: Optional[List[str]] = None,
     source_nodes_prefixes: Optional[List[str]] = None,
     destination_nodes_prefixes: Optional[List[str]] = None,
-    validation_unbalance_rates: Tuple[float] = (1.0, ),
+    validation_unbalance_rates: Union[float, Tuple[float]] = (1.0, ),
     use_scale_free_distribution: bool = True,
     enable_cache: bool = False,
     precompute_constant_stocastic_features: bool = False,
@@ -76,8 +80,14 @@ def edge_prediction_evaluation(
             help the model learn that two different components are connected.
     node_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None
         The node features to use.
+    edge_features: Optional[Union[str, Type[AbstractEdgeFeature], List[Union[str, Type[AbstractEdgeFeature]]]]] = None
+        The edge features to use.
     node_type_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None
         The node type features to use.
+    edge_type_features: Optional[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel], List[Union[str, pd.DataFrame, np.ndarray, Type[AbstractEmbeddingModel]]]]] = None
+        The edge type features to use.
+    node_features_preprocessing_steps: Optional[Union[Type[AbstractFeaturePreprocessor], List[Type[AbstractFeaturePreprocessor]]]] = None
+        The preprocessing steps to use for the node features.
     library_names: Optional[Union[str, List[str]]] = None
         Library names from where to retrieve the provided model names.
     graph_callback: Optional[Callable[[Graph], Graph]] = None
@@ -101,9 +111,6 @@ def edge_prediction_evaluation(
         from the Ensmallen automatic retrieval.
     versions: Optional[Union[str, List[str]]] = None
         Graph versions to retrieve.
-    validation_sample_only_edges_with_heterogeneous_node_types: bool = False
-        Whether to sample negative edges exclusively between nodes with different node types.
-        This can be useful when executing a bipartite edge prediction task.
     source_node_types_names: Optional[List[str]]
         Node type names of the nodes to be samples as sources.
         If a node has any of the provided node types, it can be sampled as a source node.
@@ -155,6 +162,8 @@ def edge_prediction_evaluation(
     verbose: bool = True
         Whether to show loading bars
     """
+    if isinstance(validation_unbalance_rates, float):
+        validation_unbalance_rates = (validation_unbalance_rates,)
     return classification_evaluation_pipeline(
         evaluation_schema=evaluation_schema,
         holdouts_kwargs=holdouts_kwargs,
@@ -162,7 +171,10 @@ def edge_prediction_evaluation(
         models=models,
         expected_parent_class=AbstractEdgePredictionModel,
         node_features=node_features,
+        edge_features=edge_features,
         node_type_features=node_type_features,
+        edge_type_features=edge_type_features,
+        node_features_preprocessing_steps=node_features_preprocessing_steps,
         library_names=library_names,
         graph_callback=graph_callback,
         subgraph_of_interest=subgraph_of_interest,
@@ -177,7 +189,6 @@ def edge_prediction_evaluation(
         number_of_slurm_nodes=number_of_slurm_nodes,
         slurm_node_id_variable=slurm_node_id_variable,
         verbose=verbose,
-        validation_sample_only_edges_with_heterogeneous_node_types=validation_sample_only_edges_with_heterogeneous_node_types,
         source_node_types_names=source_node_types_names,
         destination_node_types_names=destination_node_types_names,
         source_edge_types_names=source_edge_types_names,
