@@ -17,7 +17,8 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
         number_of_units_per_ffnn_body_layer: Union[int, List[int]] = 128,
         number_of_units_per_ffnn_head_layer: Union[int, List[int]] = 128,
         dropout_rate: float = 0.3,
-        edge_embedding_method: str = "Concatenate",
+        number_of_batches_per_epoch: Optional[int] = None,
+        edge_embedding_methods: Union[List[str], str] = "Concatenate",
         optimizer: Union[str, Type[Optimizer]] = "adam",
         early_stopping_min_delta: float = 0.0001,
         early_stopping_patience: int = 20,
@@ -30,16 +31,20 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
         reduce_lr_factor: float = 0.9,
         avoid_false_negatives: bool = True,
         training_unbalance_rate: float = 1.0,
-        training_sample_only_edges_with_heterogeneous_node_types: bool = False,
         use_edge_metrics: bool = False,
         random_state: int = 42,
         use_node_embedding: bool = False,
         node_embedding_size: int = 50,
         use_node_type_embedding: bool = False,
         node_type_embedding_size: int = 50,
+        use_edge_type_embedding: bool = False,
+        edge_type_embedding_size: int = 50,
+        residual_convolutional_layers: bool = False,
+        siamese_node_feature_module: bool = True,
         handling_multi_graph: str = "warn",
-        node_feature_names: Optional[List[str]] = None,
-        node_type_feature_names: Optional[List[str]] = None,
+        node_feature_names: Optional[Union[str, List[str]]] = None,
+        node_type_feature_names: Optional[Union[str, List[str]]] = None,
+        edge_type_feature_names: Optional[Union[str, List[str]]] = None,
         verbose: bool = False
     ):
         """Create new Kipf GCN object.
@@ -67,10 +72,14 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
         dropout_rate: float = 0.3
             Float between 0 and 1.
             Fraction of the input units to dropout.
+        number_of_batches_per_epoch: Optional[int] = None
+            Number of batches to use per epoch.
+            By default, this is None, which means that the number of batches
+            will be equal to the number of directed edges divided by the batch size.
         edge_embedding_method: str = "Concatenate"
             The edge embedding method to use to put togheter the
             source and destination node features, which includes:
-            - Concatenation
+            - Concatenate
             - Average
             - Hadamard
             - L1
@@ -111,18 +120,6 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
             The amount of negatives to be sampled during the training of the model.
             By default this is 1.0, which means that the same number of positives and
             negatives in the training are of the same cardinality.
-        training_sample_only_edges_with_heterogeneous_node_types: bool = False
-            Whether to sample exclusively edges between nodes with different node types.
-        use_node_embedding: bool = False
-            Whether to use a node embedding layer to let the model automatically
-            learn an embedding of the nodes.
-        node_embedding_size: int = 50
-            Size of the node embedding.
-        use_node_types: Union[bool, str] = "auto"
-            Whether to use the node types while training the model.
-            By default, automatically uses them if the graph has them.
-        node_type_embedding_size: int = 50
-            Size of the embedding for the node types.
         use_edge_metrics: bool = False
             Whether to use the edge metrics from traditional edge prediction.
             These metrics currently include:
@@ -130,8 +127,6 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
             - Jaccard Coefficient
             - Resource allocation index
             - Preferential attachment
-        use_simmetric_normalized_laplacian: bool = True
-            Whether to use laplacian transform before training on the graph.
         use_node_embedding: bool = False
             Whether to use a node embedding layer that is automatically learned
             by the model while it trains. Please do be advised that by using
@@ -146,22 +141,35 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
             and this model will not work on graphs with a different node vocabulary.
         node_type_embedding_size: int = 50
             Dimension of the node type embedding.
+        use_edge_type_embedding: bool = False
+            Whether to use a edge type embedding layer that is automatically learned
+            by the model while it trains. Please do be advised that by using
+            a edge type embedding layer you are making a closed-world assumption,
+            and this model will not work on graphs with a different edge vocabulary.
+        edge_type_embedding_size: int = 50
+            Dimension of the edge type embedding.
+        residual_convolutional_layers: bool = False
+            Whether to use residual connections between convolutional layers.
+        siamese_node_feature_module: bool = True
+            Whether to use a siamese module for the node features.
         handling_multi_graph: str = "warn"
             How to behave when dealing with multigraphs.
             Possible behaviours are:
             - "warn"
             - "raise"
             - "drop"
-        node_feature_names: Optional[List[str]] = None
+        node_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node features.
             This is used as the layer names.
-        node_type_feature_names: Optional[List[str]] = None
+        node_type_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node type features.
             This is used as the layer names.
+        edge_type_feature_names: Optional[Union[str, List[str]]] = None
         verbose: bool = False
             Whether to show loading bars.
         """
         super().__init__(
+            kernels=["Left Normalized Laplacian"],
             epochs=epochs,
             number_of_graph_convolution_layers=number_of_graph_convolution_layers,
             number_of_units_per_graph_convolution_layers=number_of_units_per_graph_convolution_layers,
@@ -170,9 +178,9 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
             number_of_units_per_ffnn_body_layer=number_of_units_per_ffnn_body_layer,
             number_of_units_per_ffnn_head_layer=number_of_units_per_ffnn_head_layer,
             dropout_rate=dropout_rate,
-            combiner="mean",
+            number_of_batches_per_epoch=number_of_batches_per_epoch,
             apply_norm=True,
-            edge_embedding_method=edge_embedding_method,
+            edge_embedding_methods=edge_embedding_methods,
             optimizer=optimizer,
             early_stopping_min_delta=early_stopping_min_delta,
             early_stopping_patience=early_stopping_patience,
@@ -185,17 +193,21 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
             reduce_lr_factor=reduce_lr_factor,
             avoid_false_negatives=avoid_false_negatives,
             training_unbalance_rate=training_unbalance_rate,
-            training_sample_only_edges_with_heterogeneous_node_types=training_sample_only_edges_with_heterogeneous_node_types,
+            
             use_edge_metrics=use_edge_metrics,
             random_state=random_state,
-            use_simmetric_normalized_laplacian=False,
             use_node_embedding=use_node_embedding,
             node_embedding_size=node_embedding_size,
             use_node_type_embedding=use_node_type_embedding,
             node_type_embedding_size=node_type_embedding_size,
+            use_edge_type_embedding=use_edge_type_embedding,
+            edge_type_embedding_size=edge_type_embedding_size,
+            residual_convolutional_layers=residual_convolutional_layers,
+            siamese_node_feature_module=siamese_node_feature_module,
             handling_multi_graph=handling_multi_graph,
             node_feature_names=node_feature_names,
             node_type_feature_names=node_type_feature_names,
+            edge_type_feature_names=edge_type_feature_names,
             verbose=verbose,
         )
 
@@ -203,7 +215,7 @@ class GraphSAGEEdgePrediction(GCNEdgePrediction):
         """Returns parameters for smoke test."""
         removed = [
             "apply_norm",
-            "use_simmetric_normalized_laplacian",
+            "kernels",
             "combiner"
         ]
         return dict(
