@@ -1,4 +1,5 @@
 """Module providing Laplacian Eigenmaps implementation."""
+from typing import Any, Dict
 from ensmallen import Graph
 import pandas as pd
 import numpy as np
@@ -71,6 +72,12 @@ class LaplacianEigenmapsEnsmallen(EnsmallenEmbedder):
             node_embeddings=embedding
         )
 
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
+        return dict(
+            embedding_size=5,
+        )
+
     @classmethod
     def model_name(cls) -> str:
         """Returns name of the model."""
