@@ -14,6 +14,8 @@ class Node2VecGloVeEnsmallen(Node2VecEnsmallen):
         window_size: int = 5,
         return_weight: float = 0.25,
         explore_weight: float = 4.0,
+        change_node_type_weight: float = 1.0,
+        change_edge_type_weight: float = 1.0,
         max_neighbours: Optional[int] = 100,
         learning_rate: float = 0.05,
         learning_rate_decay: float = 0.9,
@@ -58,6 +60,12 @@ class Node2VecGloVeEnsmallen(Node2VecEnsmallen):
             Having this very high makes search more outward.
             Having this very low makes search very local.
             Equal to the inverse of q in the Node2Vec paper.
+        change_node_type_weight: float = 1.0
+            Weight on the probability of changing the node type.
+            By default, 1.0.
+        change_edge_type_weight: float = 1.0
+            Weight on the probability of changing the edge type.
+            By default, 1.0.
         max_neighbours: Optional[int] = 100
             Number of maximum neighbours to consider when using approximated walks.
             By default, None, we execute exact random walks.
@@ -103,6 +111,8 @@ class Node2VecGloVeEnsmallen(Node2VecEnsmallen):
             window_size=window_size,
             return_weight=return_weight,
             explore_weight=explore_weight,
+            change_node_type_weight=change_node_type_weight,
+            change_edge_type_weight=change_edge_type_weight,
             max_neighbours=max_neighbours,
             learning_rate=learning_rate,
             learning_rate_decay=learning_rate_decay,
