@@ -19,6 +19,7 @@ class ScoreSPINE(EnsmallenEmbedder):
         maximum_depth: Optional[int] = None,
         path: Optional[str] = None,
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new Score-based SPINE method.
@@ -38,6 +39,8 @@ class ScoreSPINE(EnsmallenEmbedder):
             This parameter is necessary to embed very large graphs.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -56,6 +59,7 @@ class ScoreSPINE(EnsmallenEmbedder):
 
         super().__init__(
             embedding_size=embedding_size,
+            ring_bell=ring_bell,
             enable_cache=enable_cache
         )
 
