@@ -59,7 +59,7 @@ def embed_graph(
     if isinstance(embedding_model, str):
         embedding_model: Type[AbstractEmbeddingModel] = AbstractEmbeddingModel.get_model_from_library(
             model_name=embedding_model,
-            library_name=library_name
+            library_name=library_name,
         )(**kwargs)
     elif kwargs:
         raise ValueError(
