@@ -12,6 +12,7 @@ class NodeSketchKarateClub(AbstractKarateClubEmbedder):
         iterations: int = 10,
         decay: float = 0.01,
         random_state: int = 42,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Return a new NodeSketch embedding model.
@@ -27,6 +28,8 @@ class NodeSketchKarateClub(AbstractKarateClubEmbedder):
         random_state: int = 42
             Random state to use for the stocastic
             portions of the embedding algorithm.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -37,6 +40,7 @@ class NodeSketchKarateClub(AbstractKarateClubEmbedder):
         super().__init__(
             embedding_size=embedding_size,
             enable_cache=enable_cache,
+            ring_bell=ring_bell,
             random_state=random_state
         )
 
