@@ -12,31 +12,53 @@ class EdgePredictionTransformer:
 
     def __init__(
         self,
-        method: str = "Hadamard",
+        methods: Union[List[str], str] = "Hadamard",
         aligned_mapping: bool = False,
+        include_both_undirected_edges: bool = True
     ):
         """Create new EdgePredictionTransformer object.
 
         Parameters
         ------------------------
-        method: str = "hadamard",
+        methods: Union[List[str], str] = "Hadamard",
             Method to use for the embedding.
-            Can either be 'Hadamard', 'Sum', 'Average', 'L1', 'AbsoluteL1', 'L2' or 'Concatenate'.
+            If None is used, we return instead the numeric tuples.
+            If multiple edge embedding are provided, they
+            will be Concatenated and fed to the model.
+            The supported edge embedding methods are:
+             * Hadamard: element-wise product
+             * Sum: element-wise sum
+             * Average: element-wise mean
+             * L1: element-wise subtraction
+             * AbsoluteL1: element-wise subtraction in absolute value
+             * SquaredL2: element-wise subtraction in squared value
+             * L2: element-wise squared root of squared subtraction
+             * Concatenate: Concatenate of source and destination node features
+             * Min: element-wise minimum
+             * Max: element-wise maximum
+             * L2Distance: vector-wise L2 distance - this yields a scalar
+             * CosineSimilarity: vector-wise cosine similarity - this yields a scalar
         aligned_mapping: bool = False,
             This parameter specifies whether the mapping of the embeddings nodes
             matches the internal node mapping of the given graph.
             If these two mappings do not match, the generated edge embedding
             will be meaningless.
+        include_both_undirected_edges: bool = True
+            Whether to include both directed and undirected edges.
         """
         self._transformer = GraphTransformer(
-            method=method,
+            methods=methods,
             aligned_mapping=aligned_mapping,
+            include_both_undirected_edges=include_both_undirected_edges
         )
 
     def fit(
         self,
         node_feature: Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]],
-        node_type_feature: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None,
+        node_type_feature: Optional[Union[pd.DataFrame, np.ndarray,
+                                          List[Union[pd.DataFrame, np.ndarray]]]] = None,
+        edge_type_features: Optional[Union[pd.DataFrame, np.ndarray,
+                                           List[Union[pd.DataFrame, np.ndarray]]]] = None,
     ):
         """Fit the model.
 
@@ -46,6 +68,8 @@ class EdgePredictionTransformer:
             Node feature to use to fit the transformer.
         node_type_feature: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
             Node type feature to use to fit the transformer.
+        edge_type_features: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
+            Edge type feature to use to fit the transformer.
 
         Raises
         -------------------------
@@ -54,7 +78,8 @@ class EdgePredictionTransformer:
         """
         self._transformer.fit(
             node_feature,
-            node_type_feature=node_type_feature
+            node_type_feature=node_type_feature,
+            edge_type_features=edge_type_features
         )
 
     def transform(
@@ -76,7 +101,7 @@ class EdgePredictionTransformer:
             The graph whose edges are to be embedded and labeled as positives.
             It can either be an Graph or a list of lists of edges.
         edge_features: Optional[Union[np.ndarray, List[np.ndarray]]] = None
-            Optional edge features to be used as input concatenated
+            Optional edge features to be used as input Concatenated
             to the obtained edge embedding. The shape must be equal
             to the number of directed edges in the provided graph.
         random_state: int = 42,
@@ -103,34 +128,56 @@ class EdgePredictionTransformer:
                     "two graphs."
                 )
 
-        if edge_features is not None:
-            if not isinstance(edge_features, list):
-                edge_features = [edge_features]
-            
-            if isinstance(positive_graph, Graph):
-                number_of_positive_edges = positive_graph.get_number_of_directed_edges()
-            else:
-                number_of_positive_edges = len(positive_graph)
-            
-            positive_edge_features = [
-                edge_feature[:number_of_positive_edges]
-                for edge_feature in edge_features
-            ]
-            negative_edge_features  = [
-                edge_feature[number_of_positive_edges:]
-                for edge_feature in edge_features
-            ]
+        if edge_features is None:
+            edge_features = []
+
+        if not isinstance(edge_features, list):
+            edge_features = [edge_features]
+
+        if isinstance(positive_graph, Graph):
+            number_of_positive_edges = positive_graph.get_number_of_edges()
         else:
-            positive_edge_features = negative_edge_features = None
+            number_of_positive_edges = len(positive_graph)
+
+        if isinstance(negative_graph, Graph):
+            number_of_negative_edges = negative_graph.get_number_of_edges()
+        else:
+            number_of_negative_edges = len(negative_graph)
+
+        for edge_feature in edge_features:
+            if not isinstance(edge_feature, np.ndarray):
+                raise ValueError(
+                    "The provided edge features must be a numpy array. "
+                    f"Your provided edge features are of type {type(edge_feature)}."
+                )
+
+            if edge_feature.shape[0] != number_of_positive_edges + number_of_negative_edges:
+                raise ValueError(
+                    "The provided edge features must have the same number of edges as the provided graphs. "
+                    f"The provided edge features have {edge_feature.shape[0]} edges, while the provided graphs have "
+                    f"{number_of_positive_edges} and {number_of_negative_edges} edges."
+                )
+            
+        positive_edge_features = [
+            edge_feature[:number_of_positive_edges]
+            for edge_feature in edge_features
+        ]
+
+        negative_edge_features = [
+            edge_feature[number_of_positive_edges:]
+            for edge_feature in edge_features
+        ]
 
         positive_edge_embedding = self._transformer.transform(
             positive_graph,
-            node_types=positive_graph,
+            node_types=positive_graph if self._transformer.has_node_type_features() else None,
+            edge_types=positive_graph if self._transformer.has_edge_type_features() else None,
             edge_features=positive_edge_features
         )
         negative_edge_embedding = self._transformer.transform(
             negative_graph,
-            node_types=negative_graph,
+            node_types=negative_graph if self._transformer.has_node_type_features() else None,
+            edge_types=negative_graph if self._transformer.has_edge_type_features() else None,
             edge_features=negative_edge_features
         )
 
@@ -153,4 +200,4 @@ class EdgePredictionTransformer:
 
             edge_embeddings, edge_labels = edge_embeddings[indices], edge_labels[indices]
 
-        return edge_embeddings, edge_labels
\ No newline at end of file
+        return edge_embeddings, edge_labels
