@@ -1,7 +1,7 @@
 """Submodule wrapping Extra Trees for node label prediction."""
 from typing import Dict, Any
 from sklearn.ensemble import ExtraTreesClassifier
-from embiggen.node_label_prediction.node_label_prediction_sklearn.decision_tree_for_node_prediction import DecisionTreeNodeLabelPrediction
+from embiggen.node_label_prediction.node_label_prediction_sklearn.decision_tree_node_label_prediction import DecisionTreeNodeLabelPrediction
 from embiggen.node_label_prediction.node_label_prediction_sklearn.sklearn_node_label_prediction_adapter import SklearnNodeLabelPredictionAdapter
 
 
@@ -16,7 +16,7 @@ class ExtraTreesNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
         min_samples_split: int = 2,
         min_samples_leaf: int = 1,
         min_weight_fraction_leaf: float = 0.,
-        max_features="auto",
+        max_features="sqrt",
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
         bootstrap=True,
@@ -108,4 +108,10 @@ class ExtraTreesNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
     
     @classmethod
     def model_name(cls) -> str:
-        return "Extra Trees Classifier"
\ No newline at end of file
+        return "Extra Trees Classifier"
+    
+
+    @classmethod
+    def supports_multilabel_prediction(cls) -> bool:
+        """Returns whether the model supports multilabel prediction."""
+        return True
\ No newline at end of file
