@@ -9,7 +9,7 @@ class GradientBoostingNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
 
     def __init__(
         self,
-        loss='deviance',
+        loss='log_loss',
         learning_rate=0.1,
         n_estimators=100,
         subsample=1.0,
@@ -20,7 +20,7 @@ class GradientBoostingNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
         max_depth=3,
         min_impurity_decrease=0.,
         init=None,
-        max_features=None,
+        max_features="sqrt",
         verbose=0,
         max_leaf_nodes=None,
         warm_start=False,
@@ -100,4 +100,9 @@ class GradientBoostingNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
 
     @classmethod
     def model_name(cls) -> str:
-        return "Gradient Boosting Classifier"
\ No newline at end of file
+        return "Gradient Boosting Classifier"
+    
+    @classmethod
+    def supports_multilabel_prediction(cls) -> bool:
+        """Returns whether the model supports multilabel prediction."""
+        return False
