@@ -2,7 +2,7 @@
 from typing import Dict, Any
 from sklearn.ensemble import RandomForestClassifier
 from multiprocessing import cpu_count
-from embiggen.node_label_prediction.node_label_prediction_sklearn.decision_tree_for_node_prediction import DecisionTreeNodeLabelPrediction
+from embiggen.node_label_prediction.node_label_prediction_sklearn.decision_tree_node_label_prediction import DecisionTreeNodeLabelPrediction
 from embiggen.node_label_prediction.node_label_prediction_sklearn.sklearn_node_label_prediction_adapter import SklearnNodeLabelPredictionAdapter
 
 
@@ -108,4 +108,9 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
 
     @classmethod
     def model_name(cls) -> str:
-        return "Random Forest Classifier"
\ No newline at end of file
+        return "Random Forest Classifier"
+    
+    @classmethod
+    def supports_multilabel_prediction(cls) -> bool:
+        """Returns whether the model supports multilabel prediction."""
+        return True
\ No newline at end of file
