@@ -32,9 +32,10 @@ class KipfGCNNodeLabelPrediction(GCNNodeLabelPrediction):
         random_state: int = 42,
         use_node_embedding: bool = False,
         node_embedding_size: int = 50,
+        residual_convolutional_layers: bool = False,
         handling_multi_graph: str = "warn",
-        node_feature_names: Optional[List[str]] = None,
-        node_type_feature_names: Optional[List[str]] = None,
+        node_feature_names: Optional[Union[str, List[str]]] = None,
+        node_type_feature_names: Optional[Union[str, List[str]]] = None,
         verbose: bool = False
     ):
         """Create new Kipf GCN object.
@@ -88,22 +89,25 @@ class KipfGCNNodeLabelPrediction(GCNNodeLabelPrediction):
             and this model will not work on graphs with a different node vocabulary.
         node_embedding_size: int = 50
             Dimension of the node embedding.
+        residual_convolutional_layers: bool = False
+            Whether to use residual connections between convolutional layers.
         handling_multi_graph: str = "warn"
             How to behave when dealing with multigraphs.
             Possible behaviours are:
             - "warn"
             - "raise"
             - "drop"
-        node_feature_names: Optional[List[str]] = None
+        node_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node features.
             This is used as the layer names.
-        node_type_feature_names: Optional[List[str]] = None
+        node_type_feature_names: Optional[Union[str, List[str]]] = None
             Names of the node type features.
             This is used as the layer names.
         verbose: bool = False
             Whether to show loading bars.
         """
         super().__init__(
+            kernels="Symmetric Normalized Laplacian",
             epochs=epochs,
             number_of_graph_convolution_layers=number_of_graph_convolution_layers,
             number_of_head_layers=number_of_head_layers,
@@ -111,7 +115,6 @@ class KipfGCNNodeLabelPrediction(GCNNodeLabelPrediction):
             number_of_units_per_head_layer=number_of_units_per_head_layer,
             dropout_rate=dropout_rate,
             apply_norm=apply_norm,
-            combiner="sum",
             optimizer=optimizer,
             early_stopping_min_delta=early_stopping_min_delta,
             early_stopping_patience=early_stopping_patience,
@@ -124,9 +127,9 @@ class KipfGCNNodeLabelPrediction(GCNNodeLabelPrediction):
             reduce_lr_factor=reduce_lr_factor,
             use_class_weights=use_class_weights,
             random_state=random_state,
-            use_simmetric_normalized_laplacian=True,
             use_node_embedding=use_node_embedding,
             node_embedding_size=node_embedding_size,
+            residual_convolutional_layers=residual_convolutional_layers,
             handling_multi_graph=handling_multi_graph,
             node_feature_names=node_feature_names,
             node_type_feature_names=node_type_feature_names,
