@@ -1,7 +1,11 @@
 """Subclass providing EmbeddingResult object."""
-from typing import List, Union, Optional, Dict
-import pandas as pd
+import inspect
+import types
+import warnings
+from typing import Dict, List, Optional, Union
+
 import numpy as np
+import pandas as pd
 
 
 class EmbeddingResult:
@@ -95,20 +99,83 @@ class EmbeddingResult:
                     )
 
                 if np.isclose(numpy_embedding, 0.0).all():
-                    raise ValueError(
+                    warnings.warn(
                         f"One of the provided {embedding_list_name} "
                         f"computed with the {embedding_method_name} method "
                         "contains exclusively zeros."
                     )
 
-        self._embedding_method_name = embedding_method_name
-        self._node_embeddings = node_embeddings
-        self._edge_embeddings = edge_embeddings
-        self._node_type_embeddings = node_type_embeddings
-        self._edge_type_embeddings = edge_type_embeddings
+        self._embedding_method_name: str = embedding_method_name
+        self._node_embeddings: List[np.ndarray] = node_embeddings
+        self._edge_embeddings: List[np.ndarray] = edge_embeddings
+        self._node_type_embeddings: List[np.ndarray] = node_type_embeddings
+        self._edge_type_embeddings: List[np.ndarray] = edge_type_embeddings
+
+        if self.is_single_embedding():
+            embedding = self.get_single_embedding()
+            for method_name, method in inspect.getmembers(
+                embedding, lambda o: isinstance(o, types.MethodType)
+            ):
+                def metawrap(method_name: str):
+                    def wrapper(*args, **kwargs):
+                        return getattr(embedding, method_name)(
+                            *args,
+                            **kwargs
+                        )
+                    wrapper.__doc__ = method.__doc__
+                    wrapper.__name__ = method.__name__
+                    return wrapper
+
+                setattr(self, method_name, metawrap(method_name))
+
+
+    def get_single_embedding(self) -> Union[np.ndarray, pd.DataFrame]:
+        """Returns the single non-None embedding."""
+        assert self.is_single_embedding()
+        for embeddings in (
+            self._node_embeddings,
+            self._edge_embeddings,
+            self._node_type_embeddings,
+            self._edge_type_embeddings
+        ):
+            if embeddings is not None:
+                return embeddings[0]
+
+    def is_single_embedding(self) -> bool:
+        """Returns whether the wrapper contains a single embedding."""
+        return self.number_of_embeddings() == 1
+
+    def number_of_embeddings(self) -> int:
+        """Returns the number of embedding included in the wrapper."""
+        total = 0
+        for embeddings in (
+            self._node_embeddings,
+            self._edge_embeddings,
+            self._node_type_embeddings,
+            self._edge_type_embeddings
+        ):
+            if embeddings is not None:
+                total += len(embeddings)
+        return total
 
     def get_all_node_embedding(self) -> List[Union[pd.DataFrame, np.ndarray]]:
-        """Return a list with all the computed node embedding."""
+        """Return a list with all the computed node embedding.
+        
+        Implementation details
+        ----------------------
+        Different embedding methods compute a different number of node embeddings.
+        For example, the LINE method computes a single embedding for each node,
+        while an embedding based on SkipGram, such as Node2Vec SkipGram,
+        computes two embeddings for each node: one for the node context and one for the node itself.
+
+        For this reason, to standardize the access to the node embeddings,
+        this method returns a list of node embeddings.
+
+        Raises
+        ----------------
+        ValueError
+            If the node embeddings were not computed by the embedding method.
+        """
         if self._node_embeddings is None:
             raise ValueError(
                 "The node embedding were requested but they "
@@ -117,7 +184,24 @@ class EmbeddingResult:
         return self._node_embeddings
 
     def get_all_edge_embedding(self) -> List[Union[pd.DataFrame, np.ndarray]]:
-        """Return a list with all the computed edge embedding."""
+        """Return a list with all the computed edge embedding.
+        
+        Implementation details
+        ----------------------
+        Different embedding methods compute a different number of edge embeddings.
+        For example, a method such as HyperSketching produces three different edge
+        embeddings for each edge: one for the exclusive overlaps matrix, one for the
+        exclusive left difference and one for the exclusive right difference.
+
+        For this reason, to standardize the access to the edge embeddings,
+        this method returns a list of edge embeddings.
+
+        Raises
+        ----------------
+        ValueError
+            If the edge embeddings were not computed by the embedding method.
+
+        """
         if self._edge_embeddings is None:
             raise ValueError(
                 "The edge embedding were requested but they "
