@@ -1,5 +1,5 @@
 """Submodule providing auto model stub for non-mandatory modules."""
-from typing import Type, List, Union
+from typing import Type, List, Union, Dict, Any
 from embiggen.utils.abstract_models.abstract_model import AbstractModel
 from embiggen.utils.abstract_models.list_formatting import format_list
 
@@ -11,6 +11,7 @@ def get_model_or_stub(
     submodule_name: str,
     model_class_name: str,
     formatted_model_name: str,
+    task_name: str,
     parent_class: Type[AbstractModel]
 ):
     """Returns either the class or a stub with helpful error messages.
@@ -29,6 +30,8 @@ def get_model_or_stub(
         Name of the model class to load or stub.
     formatted_model_name: str
         Formatted model name to load.
+    task_name: str
+        Name of the task of the model.
     parent_class: Type[AbstractModel]
         Expected parent class of the model.
     """
@@ -87,18 +90,19 @@ def get_model_or_stub(
                 "likely an implementation error, and should be "
                 "reported to the Embiggen repository as an issue."
             )
-    except ModuleNotFoundError as e:
+    except (ModuleNotFoundError, OSError) as exception:
+        exception_message = str(exception)
         # If effectively the error is that we cannot load the desired
         # library name, we catch this and re-raise it.
         if any(
-            str(e).startswith(f"No module named '{module_library_name}")
+            str(exception).startswith(f"No module named '{module_library_name}")
+            or module_library_name in str(exception)
             for module_library_name in module_library_names
         ):
             class StubClass(parent_class):
 
-                def __init__(self, *args, **kwargs) :
+                def __init__(self, *args, **kwargs):
                     """Raises a useful error message about this class."""
-                    super().__init__(**parent_class.smoke_test_parameters())
                     self.__class__.__name__ = model_class_name
                     other_candidates = self.find_available_models(
                         self.model_name(),
@@ -131,7 +135,8 @@ def get_model_or_stub(
                             f"model {self.model_name()}, as it is based on the "
                             f"{self.library_name()} library. "
                             "Please do refer to the requested library documentation "
-                            f"to proceed with the installation. {other_candidates_message}"
+                            f"to proceed with the installation. {other_candidates_message}. "
+                            f"The original error message was: {exception_message}"
                         )
                     )
 
@@ -184,6 +189,26 @@ def get_model_or_stub(
                 def is_stocastic(cls) -> bool:
                     """Returns whether the model can optionally use edge weights."""
                     return None
+                
+                @classmethod
+                def requires_edge_type_features(cls) -> str:
+                    """Returns whether the model requires edge type features."""
+                    return None
+                
+                @classmethod
+                def can_use_edge_type_features(cls) -> bool:
+                    """Returns whether the model can optionally use edge type features."""
+                    return None
+                
+                @classmethod
+                def requires_edge_features(cls) -> str:
+                    """Returns whether the model requires edge features."""
+                    return None
+                
+                @classmethod
+                def can_use_edge_features(cls) -> bool:
+                    """Returns whether the model can optionally use edge features."""
+                    return None
 
                 @classmethod
                 def is_topological(cls) -> str:
@@ -193,7 +218,12 @@ def get_model_or_stub(
                 @classmethod
                 def task_name(cls) -> str:
                     """Returns name of the task"""
-                    return parent_class.task_name()
+                    return task_name
+
+                @classmethod
+                def smoke_test_parameters(cls) -> Dict[str, Any]:
+                    """Returns parameters for the smoke test."""
+                    return dict()
 
                 @classmethod
                 def is_available(cls) -> bool:
@@ -203,7 +233,7 @@ def get_model_or_stub(
             model_class = StubClass
         else:
             # We re-raise the exception.
-            raise e
+            raise exception
 
     # We assign the local class as exposed in the
     # caller frame.
